@@ -27,8 +27,8 @@ protected:
 
   //Child widgets:
   Gtk::Frame m_Frame;
-  Gtk::VBox m_VBox;
-  Gtk::HBox m_HBox;
+  Gtk::Box m_VBox;
+  Gtk::Box m_HBox;
   Gtk::ScrolledWindow m_ScrolledWindow;
   Glib::RefPtr<Gtk::TreeModel> m_refTreeModel;
   Gtk::TreeView m_TreeView;
@@ -64,8 +64,8 @@ Gtk::Window* do_stock_browser()
 Example_StockBrowser::Example_StockBrowser()
 :
   m_Frame("Selected Item"),
-  m_VBox(false, 8),
-  m_HBox(false, 8),
+  m_VBox(Gtk::ORIENTATION_VERTICAL, 8),
+  m_HBox(Gtk::ORIENTATION_HORIZONTAL, 8),
   m_Alignment(Gtk::ALIGN_CENTER, Gtk::ALIGN_START, 0.0, 0.0)
 {
   set_title("Stock Icons and Items");
@@ -237,10 +237,12 @@ void Example_StockBrowser::on_selection_changed()
     if(icon) //If there's a stock icon:
     {
       // find the largest size the icon comes in:
-      const Gtk::IconSet iconset = Gtk::IconSet::lookup_default(stockid);
+      const Glib::RefPtr<const Gtk::IconSet> iconset = Gtk::IconSet::lookup_default(stockid);
 
       typedef std::vector<Gtk::IconSize> type_vecSizes;
-      type_vecSizes sizes = iconset.get_sizes();
+      type_vecSizes sizes;
+      if(iconset)
+        sizes = iconset->get_sizes();
 
       Gtk::IconSize best_size = Gtk::ICON_SIZE_INVALID;
       int biggest_pixelcount = 0;
